---
hide:
    - navigation
    - toc
---

# NiveshPy

NiveshPy is a financial CLI designed for managing mutual funds and investment portfolios. It provides functionalities to fetch fund prices, manage portfolios, and calculate performance.

For more information, check out our [Getting Started page](getting-started.md).

NiveshPy is targeted towards Indian :flag_in: markets, but the API is built to support any financial security.

## Quick Start

To get started, install NiveshPy from [PyPi](https://pypi.org/project/NiveshPy/):

```sh
pip install niveshpy
```

After installing, you can simply start using NiveshPy straight from your terminal:

```sh
niveshpy <command>
```

Learn more by checking our [CLI page](cli/index.md)

## Work in progress

This project is a work in progress. The public API is still in development and unstable.

## License

This project is licensed under the MIT License. See the [LICENSE](LICENSE.md) file for more details.
